@@ -222,7 +222,7 @@ class AutoPlot():
         for plot in plots:
             if plot is not None:
                 plot.xaxis.major_label_overrides = {
-                    i: date.strftime('%b %d') for i, date in enumerate(pd.to_datetime(self.data["date"]))
+                    i: date.strftime('%b %d %Y') for i, date in enumerate(pd.to_datetime(self.data["date"]))
                 }
                 plot.xaxis.bounds   = (0, self.data.index[-1])
                 plot.sizing_mode    = 'stretch_width'
@@ -523,7 +523,8 @@ class AutoPlot():
         indis_over              = 0
         indis_below             = 0
         bottom_figs             = []
-        colours                 = ['red', 'blue', 'orange', 'green']
+        colours                 = ['red', 'blue', 'orange', 'green', 'black',
+                                   'yellow']
         
         for indicator in indicators:
             indi_type = indicators[indicator]['type']
@@ -554,7 +555,7 @@ class AutoPlot():
                                         indicators[indicator]['data'], 
                                         line_width = 1.5, 
                                         legend_label = indicator,
-                                        line_color = colours[indis_over])
+                                        line_color = indicators[indicator]['color'] if 'color' in indicators[indicator] else colours[indis_over])
                     indis_over     += 1
                     
                 elif plot_type[indi_type] == 'below' and indis_below < self.max_indis_below:
