@@ -23,6 +23,7 @@ import timeit
 from scipy.optimize import brute
 from ast import literal_eval
 from autotrader.brokers.oanda import Oanda
+# from autotrader.brokers.interactive_brokers import ib_broker
 from autotrader.brokers.virtual.virtual_broker import Broker
 from autotrader.lib import instrument_list, environment_manager, printout
 from autotrader.lib.read_yaml import read_yaml
@@ -41,7 +42,7 @@ class AutoTrader():
     
     Author: Kieran Mackle
     
-    Version: 0.4.x
+    Version: 0.5.x
 
     Attributes
     ----------
@@ -115,6 +116,7 @@ class AutoTrader():
         self.order_summary_fp = None
         
         self.verbosity      = 1
+        self.broker_verbosity = 0
         self.notify         = 0
         self.email_params   = None
         self.show_help      = None
@@ -257,6 +259,9 @@ class AutoTrader():
             # Overwrite default account in global config
             broker_config['ACCOUNT_ID'] = self.account_id
         
+        # Append broker verbosity to broker_config
+        broker_config['verbosity'] = self.broker_verbosity
+        
         self._assign_broker(broker_config)
         self._configure_emailing(global_config)
         
@@ -308,7 +313,7 @@ class AutoTrader():
             # Check data lengths of each bot
             self._check_bot_data()
             
-            print("\nTrading...")
+            print("\nTrading...\n")
         
         if not self.detach_bot:
             start_range, end_range = self.bots_deployed[0]._get_iteration_range()
@@ -810,40 +815,50 @@ class AutoTrader():
         '''
         
         if self.backtest_mode is True:
-                utils_module    = importlib.import_module('autotrader.brokers.virtual.utils')
-                
-                utils           = utils_module.Utils()
-                broker          = Broker(broker_config, utils)
-                
-                initial_deposit = self.backtest_initial_balance
-                spread          = self.backtest_spread
-                leverage        = self.backtest_leverage
-                commission      = self.backtest_commission
-                base_currency   = self.backtest_base_currency
-                
-                broker.make_deposit(initial_deposit)
-                broker.fee      = spread
-                broker.leverage = leverage
-                broker.commission = commission
-                broker.spread   = spread
-                broker.base_currency = base_currency
-                # self.get_data.base_currency = base_currency
-                
-                if int(self.verbosity) > 0:
-                    banner = pyfiglet.figlet_format("AutoBacktest")
-                    print(banner)
+            # Backtesting; use virtual broker
+            utils_module    = importlib.import_module('autotrader.brokers.virtual.utils')
+            
+            utils           = utils_module.Utils()
+            broker          = Broker(broker_config, utils)
+            
+            initial_deposit = self.backtest_initial_balance
+            spread          = self.backtest_spread
+            leverage        = self.backtest_leverage
+            commission      = self.backtest_commission
+            base_currency   = self.backtest_base_currency
+            
+            broker.make_deposit(initial_deposit)
+            broker.fee      = spread
+            broker.leverage = leverage
+            broker.commission = commission
+            broker.spread   = spread
+            broker.base_currency = base_currency
+            # self.get_data.base_currency = base_currency
+            
+            if int(self.verbosity) > 0:
+                banner = pyfiglet.figlet_format("AutoBacktest")
+                print(banner)
                 
                 
         else:
-            
+            # Live/demo trading
             if self.feed.lower() == 'yahoo':
+                # Assign virtual broker for Yahoo API
                 utils_module    = importlib.import_module('autotrader.brokers.virtual.utils')
                 utils           = utils_module.Utils()
                 broker          = Broker(broker_config, utils)
-            else:
+                
+            elif self.feed.lower() == 'oanda':
+                # Oanda v20 API
                 utils_module    = importlib.import_module('autotrader.brokers.{}.utils'.format(self.feed.lower()))
                 utils           = utils_module.Utils()
-                broker          = Oanda.Oanda(broker_config, utils) # TODO - generalise away from Oanda
+                broker          = Oanda.Oanda(broker_config, utils)
+                
+            elif self.feed.lower() == 'ib':
+                # Interactive Brokers API
+                utils_module    = importlib.import_module('autotrader.brokers.interactive_brokers.utils')
+                utils           = utils_module.Utils()
+                # broker          = ib_broker.interac_broker(broker_config, utils)
         
         self.broker = broker
         self.broker_utils = utils
@@ -1229,7 +1244,7 @@ class AutoTrader():
         data_lengths = [len(bot.data) for bot in self.bots_deployed]
         
         if min(data_lengths) != np.mean(data_lengths):
-            print("Warning: mismatched data lengths detected. Correcting via row reduction.")
+            print("\nWarning: mismatched data lengths detected. Correcting via row reduction.")
             self._normalise_bot_data()
     
     def _normalise_bot_data(self):
