@@ -6,8 +6,6 @@ Purpose: AutoTrader virtual broker for backtesting
 Author: Kieran Mackle
 
 TODO: 
-    - add flag to signal long positions only allowed (eg. no CFD)
-    - include long_units and short_units in trade dictionaries
     - rename variables to clarify (eg. open_positions -> open_trades, etc)
     
 Known bug:
@@ -77,6 +75,7 @@ class Broker():
         self.NAV                = 0
         self.unrealised_PL      = 0
         self.utils              = utils
+        self.verbosity          = broker_config['verbosity']
         
 
     def place_order(self, order_details):
@@ -87,20 +86,50 @@ class Broker():
         size        = order_details["size"]
         order_price = order_details["order_price"]
         stop_loss  = order_details["stop_loss"]
-        stop_distance = order_details['stop_distance']
+        stop_distance = order_details["stop_distance"]
+        take_profit = order_details["take_profit"]
         
         if stop_loss is None and stop_distance is not None:
             pip_value   = self.utils.get_pip_ratio(instrument)
             stop_loss  = order_price - np.sign(size)*stop_distance*pip_value
         
         order_no = self.total_trades + 1
-        
-        # Create new_position and add position to self.pending_orders
         new_position = order_details.copy()
         new_position['order_ID'] = order_no
         
-        self.pending_orders[order_no] = new_position
+        # Verify SL and TP prices
+        invalid_order = False
+        if np.sign(size)*(order_price - stop_loss) < 0:
+            direction = 'long' if np.sign(size) > 0 else 'short'
+            SL_placement = 'below' if np.sign(size) > 0 else 'above'
+            if self.verbosity > 0:
+                print("Invalid stop loss request: stop loss must be "+ \
+                                f"{SL_placement} the order price for a {direction}" + \
+                                " trade order.\n"+ \
+                                f"Order Price: {order_price}\nStop Loss: {stop_loss}")
+            invalid_order = True
         
+        if take_profit is not None and np.sign(size)*(order_price - take_profit) > 0:
+            direction = 'long' if np.sign(size) > 0 else 'short'
+            TP_placement = 'above' if np.sign(size) > 0 else 'below'
+            if self.verbosity > 0:
+                print("Invalid take profit request: take profit must be "+ \
+                                f"{TP_placement} the order price for a {direction}" + \
+                                " trade order.\n"+ \
+                                f"Order Price: {order_price}\nTake Profit: {take_profit}")
+            invalid_order = True
+        
+        if invalid_order:
+            if self.verbosity > 0:
+                print(f"  Order {order_no} rejected.\n")
+            # Add position to self.pending_orders
+            self.cancelled_orders[order_no] = new_position
+            self.cancelled_orders[order_no]['reason'] = "Invalid order request"
+            
+        else:
+            # Add position to self.pending_orders
+            self.pending_orders[order_no] = new_position
+            
         # Update trade tally
         self.total_trades += 1
     
@@ -678,3 +707,8 @@ class Broker():
     def get_margin_available(self):
         ''' Returns the margin available on the account. '''
         return self.margin_available
+    
+    def modify_order(self):
+        ''' Modify order with updated parameters. '''
+        # Placeholder method
+        # can be used to update stop loss orders, to allow custom function SL
\ No newline at end of file
